.. image:: https://travis-ci.org/baminou/Uperations-Base.svg?branch=master
    :target: https://travis-ci.org/baminou/Uperations-Base


===============
Uperations-Base
===============

This library is the core library of the `Uperations project <https://www.github.com/baminou/uperations>`_. In order to use the operations
listed in this repository, you need to import this library to import this library to your project.